import React from 'react';
import { mount } from 'enzyme';
import toJson from 'enzyme-to-json';
import Button from '../index';
describe('Button', function () {
  it('should emit click event', function () {
    var onClick = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      onClick: onClick
    }, "Click"));
    wrapper.simulate('click');
    expect(onClick).toBeCalled();
  });
  it('should not emit click event when disabled', function () {
    var onClick = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      disabled: true,
      onClick: onClick
    }, "disabled"));
    wrapper.simulate('click');
    expect(onClick).not.toBeCalled();
  });
  it('should not emit click event when loading', function () {
    var onClick = jest.fn();
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      loading: true,
      onClick: onClick
    }, "loading"));
    wrapper.simulate('click');
    expect(onClick).not.toBeCalled();
  });
  it('should hide border when color is gradient', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      color: "linear-gradient(#000, #fff)"
    }));
    expect(wrapper.getDOMNode().style.border).toEqual('0px');
  });
  it('should change icon class prefix when using icon-prefix prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      icon: "success",
      iconPrefix: "my-icon"
    }));
    expect(toJson(wrapper.html())).toMatchSnapshot();
  });
  it('should render loading of a specific size when using loading-size prop', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      loading: true,
      loadingSize: "10px"
    }));
    var loading = wrapper.find('.rc-loading__spinner');
    expect(loading.getDOMNode().style.width).toEqual('10px');
    expect(loading.getDOMNode().style.height).toEqual('10px');
  });
  it('should render icon in the right side when setting icon-position to right', function () {
    var wrapper = mount( /*#__PURE__*/React.createElement(Button, {
      icon: "plus",
      iconPosition: "right"
    }));
    expect(toJson(wrapper)).toMatchSnapshot();
  });
});