import _extends from "@babel/runtime/helpers/esm/extends";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
var _excluded = ["width", "title", "theme", "visible", "message", "className", "messageAlign", "closeIcon", "closeable", "closeOnClickOverlay", "onClickCloseIcon"];
import React, { isValidElement } from 'react';
import classnames from 'classnames';
import Icon from '../icon';
import Popup from '../popup';
import Button from '../button';
import { createNamespace, addUnit, noop } from '../utils';
import { BORDER_TOP, BORDER_LEFT } from '../utils/constant';

var _createNamespace = createNamespace('dialog'),
    _createNamespace2 = _slicedToArray(_createNamespace, 1),
    bem = _createNamespace2[0];

var Dialog = function Dialog(props) {
  var width = props.width,
      title = props.title,
      theme = props.theme,
      visible = props.visible,
      message = props.message,
      className = props.className,
      messageAlign = props.messageAlign,
      closeIcon = props.closeIcon,
      closeable = props.closeable,
      closeOnClickOverlay = props.closeOnClickOverlay,
      onClickCloseIcon = props.onClickCloseIcon,
      others = _objectWithoutProperties(props, _excluded);

  var renderTitle = function renderTitle() {
    if (props.title) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('header', {
          isolated: !props.message && !props.children
        }))
      }, title);
    }

    return null;
  };

  var renderContent = function renderContent() {
    if (props.children) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('content'))
      }, props.children);
    }

    if (message) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('content', {
          isolated: !title
        }))
      }, /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('message', _defineProperty({
          'has-title': title
        }, messageAlign, messageAlign)))
      }, message));
    }

    return null;
  };

  var renderButtons = function renderButtons() {
    var _props$cancelProps, _props$cancelProps2, _props$cancelProps3, _props$confirmProps, _props$confirmProps2, _props$confirmProps3;

    return /*#__PURE__*/React.createElement("div", {
      className: classnames(theme === 'round-button' ? '' : BORDER_TOP, bem('footer'))
    }, props.showCancelButton && /*#__PURE__*/React.createElement(Button, {
      size: "large",
      text: props.cancelButtonText || '取消',
      className: classnames(bem('cancel')),
      style: {
        color: props.cancelButtonColor
      },
      loading: (_props$cancelProps = props.cancelProps) === null || _props$cancelProps === void 0 ? void 0 : _props$cancelProps.loading,
      disabled: (_props$cancelProps2 = props.cancelProps) === null || _props$cancelProps2 === void 0 ? void 0 : _props$cancelProps2.disabled,
      onClick: (_props$cancelProps3 = props.cancelProps) !== null && _props$cancelProps3 !== void 0 && _props$cancelProps3.loading ? noop : props.onCancel
    }), props.showConfirmButton && /*#__PURE__*/React.createElement(Button, {
      size: "large",
      type: theme === 'round-button' ? 'primary' : 'default',
      text: props.confirmButtonText || '确认',
      className: classnames(bem('confirm'), theme === 'round-button' ? '' : _defineProperty({}, BORDER_LEFT, props.showCancelButton)),
      round: theme === 'round-button',
      style: {
        color: props.confirmButtonColor
      },
      loading: (_props$confirmProps = props.confirmProps) === null || _props$confirmProps === void 0 ? void 0 : _props$confirmProps.loading,
      disabled: (_props$confirmProps2 = props.confirmProps) === null || _props$confirmProps2 === void 0 ? void 0 : _props$confirmProps2.disabled,
      onClick: (_props$confirmProps3 = props.confirmProps) !== null && _props$confirmProps3 !== void 0 && _props$confirmProps3.loading ? noop : props.onConfirm
    }));
  };

  var renderCloseIcon = function renderCloseIcon() {
    if (!closeable) return null;

    if (typeof props.closeIcon === 'string') {
      return /*#__PURE__*/React.createElement(Icon, {
        name: props.closeIcon,
        className: classnames(bem('close-icon')),
        onClick: function onClick() {
          var _props$onClose;

          if (onClickCloseIcon) {
            onClickCloseIcon();
          }

          (_props$onClose = props.onClose) === null || _props$onClose === void 0 ? void 0 : _props$onClose.call(props);
        }
      });
    }

    if ( /*#__PURE__*/isValidElement(props.closeIcon)) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('close-icon')),
        onClick: function onClick() {
          var _props$onClose2;

          if (onClickCloseIcon) {
            onClickCloseIcon();
          }

          (_props$onClose2 = props.onClose) === null || _props$onClose2 === void 0 ? void 0 : _props$onClose2.call(props);
        }
      }, props.closeIcon);
    }

    return null;
  };

  return /*#__PURE__*/React.createElement(Popup, _extends({}, others, {
    visible: visible,
    className: classnames(bem([theme]), className),
    style: {
      width: addUnit(width)
    },
    "aria-labelledby": title || message,
    closeOnClickOverlay: closeOnClickOverlay,
    onClose: props.onClose,
    onClosed: props.onClosed
  }), renderCloseIcon(), renderTitle(), renderContent(), renderButtons());
};

Dialog.defaultProps = {
  closeIcon: 'cross',
  transition: 'rc-dialog-bounce',
  showConfirmButton: true,
  closeOnPopstate: true
};
export default Dialog;