import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useRef, useEffect } from 'react';
import classnames from 'classnames';
import Swipe from '../swipe';
import { createNamespace } from '../utils';

var _createNamespace = createNamespace('tabs'),
    _createNamespace2 = _slicedToArray(_createNamespace, 1),
    bem = _createNamespace2[0];

var TabsContent = function TabsContent(props) {
  var swipeRef = useRef();
  var innerEffect = useRef(false);
  var animated = props.animated,
      swipeable = props.swipeable,
      duration = props.duration;

  var renderChildren = function renderChildren() {
    if (animated || swipeable) {
      return /*#__PURE__*/React.createElement(Swipe, {
        ref: swipeRef,
        loop: false,
        autoplay: false,
        allowTouchMove: swipeable,
        className: classnames(bem('track')),
        duration: +duration,
        showIndicators: false,
        onChange: function onChange(idx) {
          if (innerEffect.current) {
            innerEffect.current = false;
            return;
          }

          if (props.onChange) props.onChange(idx);
        }
      }, React.Children.map(props.children, function (child) {
        return /*#__PURE__*/React.createElement(Swipe.Item, {
          role: "tabpanel",
          style: {
            cursor: !swipeable ? 'auto' : undefined
          },
          className: classnames(bem('pane-wrapper'))
        }, child);
      }));
    }

    return props.children;
  };

  var swipeToCurrentTab = function swipeToCurrentTab(index) {
    var swipe = swipeRef.current;
    if (!swipe) return;

    if (swipe.activeIndex !== index) {
      innerEffect.current = true;
      swipe.slideTo(index, !props.inited ? 0 : +duration);
    }
  };

  useEffect(function () {
    swipeToCurrentTab(props.currentIndex);
  }, [props.currentIndex]);
  return /*#__PURE__*/React.createElement("div", {
    className: classnames(bem('content', {
      animated: animated || swipeable
    }))
  }, renderChildren());
};

export default TabsContent;